==> eslint-config-kiat-1.0.3.tgz: package/config.js <==
'use strict';

const INDENT_SPACE = 4;

module.exports = {
    env: {
        es6: true,
        node: true
    },
    extends: 'eslint:recommended',
    parserOptions: {
        ecmaVersion: 6
    },
    rules: {
		//style
		complexity: ["warn", 30],
		'max-depth': ["error", 4],
		'max-len': ["error", {ignoreStrings: true, ignoreTemplateLiterals: true}]
		
        'array-bracket-spacing': ['error', 'never'],
        'arrow-body-style': ['error', 'as-needed'],
        'arrow-parens': ['error', 'as-needed'],
        'arrow-spacing': 'error',
        'block-spacing': ['error', 'never'],
        'brace-style': 'error',
        'comma-dangle': 0,
        'comma-spacing': ['error', {before: false, after: true}],
        'comma-style': ['error', 'last'],
        'computed-property-spacing': ['error', 'never'],
        curly: 'error',
        'default-case': 'warn',
        'dot-location': ['error', 'property'],
        'dot-notation': 'error',
        'eol-last': 'error',
        eqeqeq: 'error',
        'global-require': 'off',
        'guard-for-in': 'warn',
        'handle-callback-err': 'error',
        'implicit-arrow-linebreak': ['error', 'beside'],
        indent: ['error', INDENT_SPACE, {SwitchCase: 1}],
        'key-spacing': ['error', {beforeColon: false, afterColon: true}],
        'keyword-spacing': ['error', {before: true, after: true}],
        'line-comment-position': ['error', {position: 'above'}],
        'lines-around-comment': ['error', {beforeLineComment: true}],
        'max-len': ['warn', {code: 120, ignoreComments: true}],
        'new-cap': ['warn', {capIsNew: false}],
        'no-cond-assign': 'warn',
        'no-constant-condition': 'warn',
        'no-duplicate-imports': 'error',
        'no-empty-function': 'error',
        'no-extra-parens': ['error', 'all', {nestedBinaryExpressions: false}],
        'no-floating-decimal': 'error',
        'no-implicit-coercion': 'error',
        'no-invalid-this': 'error',
        'no-lone-blocks': 'error',
        'no-loop-func': 'error',
        'no-magic-numbers': 'error',
        'no-multi-spaces': 'error',
        'no-multi-str': 'error',
        'no-new': 'error',
        'no-trailing-spaces': 'warn',
        'no-var': 'error',
        'no-warning-comments': 'warn',
        'no-whitespace-before-property': 'error',
        'object-curly-spacing': 'error',
        'one-var-declaration-per-line': ['error', 'always'],
        'operator-linebreak': ['error', 'before'],
        'prefer-arrow-callback': 'error',
        'prefer-const': 'error',
        'prefer-numeric-literals': 'error',
        'prefer-rest-params': 'error',
        'prefer-template': 'error',
        'quote-props': ['error', 'as-needed'],
        quotes: ['error', 'single'],
        'rest-spread-spacing': 'error',
        semi: ['error', 'always'],
        'semi-spacing': 'error',
        'semi-style': ['error', 'last'],
        'space-before-blocks': 'error',
        'space-in-parens': ['error', 'never'],
        'space-unary-ops': ['error', {words: true, nonwords: false}],
        'spaced-comment': ['error', 'always'],
        strict: 'error',
        'switch-colon-spacing': 'error',
        'template-curly-spacing': 'error'
    }
};

==> eslint-config-kiat-1.0.4.tgz: package/config.js <==
'use strict';

const INDENT_SPACE = 4;

module.exports = {
    env: {
        es6: true,
        node: true
    },
    extends: 'eslint:recommended',
    parserOptions: {
        ecmaVersion: 6
    },
    rules: {
		//style
		complexity: ["warn", 30],
		'max-depth': ["error", 4],
		'max-len': ["error", {ignoreStrings: true, ignoreTemplateLiterals: true}],
		
        'array-bracket-spacing': ['error', 'never'],
        'arrow-body-style': ['error', 'as-needed'],
        'arrow-parens': ['error', 'as-needed'],
        'arrow-spacing': 'error',
        'block-spacing': ['error', 'never'],
        'brace-style': 'error',
        'comma-dangle': 0,
        'comma-spacing': ['error', {before: false, after: true}],
        'comma-style': ['error', 'last'],
        'computed-property-spacing': ['error', 'never'],
        curly: 'error',
        'default-case': 'warn',
        'dot-location': ['error', 'property'],
        'dot-notation': 'error',
        'eol-last': 'error',
        eqeqeq: 'error',
        'global-require': 'off',
        'guard-for-in': 'warn',
        'handle-callback-err': 'error',
        'implicit-arrow-linebreak': ['error', 'beside'],
        indent: ['error', INDENT_SPACE, {SwitchCase: 1}],
        'key-spacing': ['error', {beforeColon: false, afterColon: true}],
        'keyword-spacing': ['error', {before: true, after: true}],
        'line-comment-position': ['error', {position: 'above'}],
        'lines-around-comment': ['error', {beforeLineComment: true}],
        'max-len': ['warn', {code: 120, ignoreComments: true}],
        'new-cap': ['warn', {capIsNew: false}],
        'no-cond-assign': 'warn',
        'no-constant-condition': 'warn',
        'no-duplicate-imports': 'error',
        'no-empty-function': 'error',
        'no-extra-parens': ['error', 'all', {nestedBinaryExpressions: false}],
        'no-floating-decimal': 'error',
        'no-implicit-coercion': 'error',
        'no-invalid-this': 'error',
        'no-lone-blocks': 'error',
        'no-loop-func': 'error',
        'no-magic-numbers': 'error',
        'no-multi-spaces': 'error',
        'no-multi-str': 'error',
        'no-new': 'error',
        'no-trailing-spaces': 'warn',
        'no-var': 'error',
        'no-warning-comments': 'warn',
        'no-whitespace-before-property': 'error',
        'object-curly-spacing': 'error',
        'one-var-declaration-per-line': ['error', 'always'],
        'operator-linebreak': ['error', 'before'],
        'prefer-arrow-callback': 'error',
        'prefer-const': 'error',
        'prefer-numeric-literals': 'error',
        'prefer-rest-params': 'error',
        'prefer-template': 'error',
        'quote-props': ['error', 'as-needed'],
        quotes: ['error', 'single'],
        'rest-spread-spacing': 'error',
        semi: ['error', 'always'],
        'semi-spacing': 'error',
        'semi-style': ['error', 'last'],
        'space-before-blocks': 'error',
        'space-in-parens': ['error', 'never'],
        'space-unary-ops': ['error', {words: true, nonwords: false}],
        'spaced-comment': ['error', 'always'],
        strict: 'error',
        'switch-colon-spacing': 'error',
        'template-curly-spacing': 'error'
    }
};
